@@ -1,23 +1,37 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2016-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2016 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "fieldgrouptest.h"
 #include "fieldgroup.h"
-#include "parametermap_p.h"
-#include "vcardtool_p.h"
-#include <QTest>
+#include "vcardtool.h"
+#include <qtest.h>
 
 FieldGroupTest::FieldGroupTest(QObject *parent)
     : QObject(parent)
 {
+
 }
 
 FieldGroupTest::~FieldGroupTest()
 {
+
 }
 
 void FieldGroupTest::shouldHaveDefaultValue()
@@ -25,7 +39,7 @@ void FieldGroupTest::shouldHaveDefaultValue()
     KContacts::FieldGroup fieldgroup;
     QVERIFY(!fieldgroup.isValid());
     QVERIFY(fieldgroup.fieldGroupName().isEmpty());
-    QVERIFY(fieldgroup.params().empty());
+    QVERIFY(fieldgroup.parameters().isEmpty());
     QVERIFY(fieldgroup.value().isEmpty());
 }
 
@@ -33,18 +47,19 @@ void FieldGroupTest::shouldAssignValue()
 {
     const QString fielgroundname(QStringLiteral("fr"));
     const QString value(QStringLiteral("bla"));
-    KContacts::ParameterMap params;
-    params.push_back({QStringLiteral("Foo1"), {QStringLiteral("bla1"), QStringLiteral("blo1")}});
-    params.push_back({QStringLiteral("Foo2"), {QStringLiteral("bla2"), QStringLiteral("blo2")}});
+    QMap<QString, QStringList> params;
+    params.insert(QStringLiteral("Foo1"), QStringList() << QStringLiteral("bla1") << QStringLiteral("blo1"));
+    params.insert(QStringLiteral("Foo2"), QStringList() << QStringLiteral("bla2") << QStringLiteral("blo2"));
     KContacts::FieldGroup fieldGroup(fielgroundname);
-    fieldGroup.setParams(params);
+    fieldGroup.setParameters(params);
     fieldGroup.setValue(value);
     QVERIFY(fieldGroup.isValid());
     QVERIFY(!fieldGroup.fieldGroupName().isEmpty());
     QCOMPARE(fieldGroup.fieldGroupName(), fielgroundname);
-    QVERIFY(!fieldGroup.params().empty());
-    QCOMPARE(fieldGroup.params(), params);
+    QVERIFY(!fieldGroup.parameters().isEmpty());
+    QCOMPARE(fieldGroup.parameters(), params);
     QCOMPARE(fieldGroup.value(), value);
+
 }
 
 void FieldGroupTest::shouldAssignExternal()
@@ -68,10 +83,10 @@ void FieldGroupTest::shouldSerialized()
     const QString value(QStringLiteral("bla"));
     fieldGroup.setValue(value);
 
-    KContacts::ParameterMap params;
-    params.push_back({QStringLiteral("Foo1"), {QStringLiteral("bla1"), QStringLiteral("blo1")}});
-    params.push_back({QStringLiteral("Foo2"), {QStringLiteral("bla2"), QStringLiteral("blo2")}});
-    fieldGroup.setParams(params);
+    QMap<QString, QStringList> params;
+    params.insert(QStringLiteral("Foo1"), QStringList() << QStringLiteral("bla1") << QStringLiteral("blo1"));
+    params.insert(QStringLiteral("Foo2"), QStringList() << QStringLiteral("bla2") << QStringLiteral("blo2"));
+    fieldGroup.setParameters(params);
 
     QByteArray data;
     QDataStream s(&data, QIODevice::WriteOnly);
@@ -81,6 +96,7 @@ void FieldGroupTest::shouldSerialized()
     t >> result;
 
     QVERIFY(fieldGroup == result);
+
 }
 
 void FieldGroupTest::shouldEqualFieldGroup()
@@ -91,10 +107,10 @@ void FieldGroupTest::shouldEqualFieldGroup()
     const QString value(QStringLiteral("bla"));
     fieldGroup.setValue(value);
     fieldGroup.setFieldGroupName(lang);
-    KContacts::ParameterMap params;
-    params.push_back({QStringLiteral("Foo1"), {QStringLiteral("bla1"), QStringLiteral("blo1")}});
-    params.push_back({QStringLiteral("Foo2"), {QStringLiteral("bla2"), QStringLiteral("blo2")}});
-    fieldGroup.setParams(params);
+    QMap<QString, QStringList> params;
+    params.insert(QStringLiteral("Foo1"), QStringList() << QStringLiteral("bla1") << QStringLiteral("blo1"));
+    params.insert(QStringLiteral("Foo2"), QStringList() << QStringLiteral("bla2") << QStringLiteral("blo2"));
+    fieldGroup.setParameters(params);
 
     result = fieldGroup;
     QVERIFY(fieldGroup == result);
@@ -102,16 +118,15 @@ void FieldGroupTest::shouldEqualFieldGroup()
 
 void FieldGroupTest::shouldParseFieldGroup()
 {
-    QByteArray vcarddata(
-        "BEGIN:VCARD\n"
-        "VERSION:3.0\n"
-        "N:LastName;FirstName;;;\n"
-        "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-        "REV:2015-03-14T09:24:45+00:00\n"
-        "FN:FirstName LastName\n"
-        "fr.foo:bla\n"
-        "fr2.foo:bla\n"
-        "END:VCARD\n");
+    QByteArray vcarddata("BEGIN:VCARD\n"
+                         "VERSION:3.0\n"
+                         "N:LastName;FirstName;;;\n"
+                         "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
+                         "REV:2015-03-14T09:24:45+00:00\n"
+                         "FN:FirstName LastName\n"
+                         "fr.foo:bla\n"
+                         "fr2.foo:bla\n"
+                         "END:VCARD\n");
 
     KContacts::VCardTool vcard;
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
@@ -121,14 +136,13 @@ void FieldGroupTest::shouldParseFieldGroup()
 
 void FieldGroupTest::shouldParseWithoutFieldGroup()
 {
-    QByteArray vcarddata(
-        "BEGIN:VCARD\n"
-        "VERSION:3.0\n"
-        "N:LastName;FirstName;;;\n"
-        "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-        "REV:2015-03-14T09:24:45+00:00\n"
-        "FN:FirstName LastName\n"
-        "END:VCARD\n");
+    QByteArray vcarddata("BEGIN:VCARD\n"
+                         "VERSION:3.0\n"
+                         "N:LastName;FirstName;;;\n"
+                         "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
+                         "REV:2015-03-14T09:24:45+00:00\n"
+                         "FN:FirstName LastName\n"
+                         "END:VCARD\n");
 
     KContacts::VCardTool vcard;
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
@@ -151,14 +165,13 @@ void FieldGroupTest::shouldCreateVCard()
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
-    QByteArray expected(
-        "BEGIN:VCARD\r\n"
-        "VERSION:4.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "UID:testuid\r\n"
-        "fr:bla\r\n"
-        "END:VCARD\r\n\r\n");
+    QByteArray expected("BEGIN:VCARD\r\n"
+                        "VERSION:4.0\r\n"
+                        "EMAIL:foo@kde.org\r\n"
+                        "N:;;;;\r\n"
+                        "UID:testuid\r\n"
+                        "fr:bla\r\n"
+                        "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
 }
@@ -181,17 +194,17 @@ void FieldGroupTest::shouldCreateVCardWithTwoLang()
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
-    QByteArray expected(
-        "BEGIN:VCARD\r\n"
-        "VERSION:4.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "UID:testuid\r\n"
-        "fr:bla\r\n"
-        "fr2:bla\r\n"
-        "END:VCARD\r\n\r\n");
+    QByteArray expected("BEGIN:VCARD\r\n"
+                        "VERSION:4.0\r\n"
+                        "EMAIL:foo@kde.org\r\n"
+                        "N:;;;;\r\n"
+                        "UID:testuid\r\n"
+                        "fr:bla\r\n"
+                        "fr2:bla\r\n"
+                        "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
+
 }
 
 void FieldGroupTest::shouldCreateVCardWithParameters()
@@ -203,24 +216,23 @@ void FieldGroupTest::shouldCreateVCardWithParameters()
     const QString value(QStringLiteral("bla"));
     KContacts::FieldGroup::List lstFieldGroup;
     KContacts::FieldGroup fieldGroup(QStringLiteral("fr"));
-    KContacts::ParameterMap params;
-    params.push_back({QStringLiteral("Foo1"), {QStringLiteral("bla1"), QStringLiteral("blo1")}});
-    params.push_back({QStringLiteral("Foo2"), {QStringLiteral("bla2"), QStringLiteral("blo2")}});
-    fieldGroup.setParams(params);
+    QMap<QString, QStringList> params;
+    params.insert(QStringLiteral("Foo1"), QStringList() << QStringLiteral("bla1") << QStringLiteral("blo1"));
+    params.insert(QStringLiteral("Foo2"), QStringList() << QStringLiteral("bla2") << QStringLiteral("blo2"));
+    fieldGroup.setParameters(params);
     fieldGroup.setValue(value);
     lstFieldGroup << fieldGroup;
     addr.setFieldGroupList(lstFieldGroup);
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
-    QByteArray expected(
-        "BEGIN:VCARD\r\n"
-        "VERSION:4.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "UID:testuid\r\n"
-        "fr;FOO1=bla1,blo1;FOO2=bla2,blo2:bla\r\n"
-        "END:VCARD\r\n\r\n");
+    QByteArray expected("BEGIN:VCARD\r\n"
+                        "VERSION:4.0\r\n"
+                        "EMAIL:foo@kde.org\r\n"
+                        "N:;;;;\r\n"
+                        "UID:testuid\r\n"
+                        "fr;FOO1=bla1,blo1;FOO2=bla2,blo2:bla\r\n"
+                        "END:VCARD\r\n\r\n");
     QCOMPARE(ba, expected);
 }
 
@@ -232,10 +244,10 @@ void FieldGroupTest::shouldNotGenerateFieldGroupForVCard3()
     addr.setUid(QStringLiteral("testuid"));
     KContacts::FieldGroup::List lstFieldGroup;
     KContacts::FieldGroup fieldGroup(QStringLiteral("fr"));
-    KContacts::ParameterMap params;
-    params.push_back({QStringLiteral("Foo1"), {QStringLiteral("bla1"), QStringLiteral("blo1")}});
-    params.push_back({QStringLiteral("Foo2"), {QStringLiteral("bla2"), QStringLiteral("blo2")}});
-    fieldGroup.setParams(params);
+    QMap<QString, QStringList> params;
+    params.insert(QStringLiteral("Foo1"), QStringList() << QStringLiteral("bla1") << QStringLiteral("blo1"));
+    params.insert(QStringLiteral("Foo2"), QStringList() << QStringLiteral("bla2") << QStringLiteral("blo2"));
+    fieldGroup.setParameters(params);
     const QString value(QStringLiteral("bla"));
     fieldGroup.setValue(value);
     lstFieldGroup << fieldGroup;
@@ -243,14 +255,13 @@ void FieldGroupTest::shouldNotGenerateFieldGroupForVCard3()
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v3_0);
-    QByteArray expected(
-        "BEGIN:VCARD\r\n"
-        "VERSION:3.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "UID:testuid\r\n"
-        "fr;FOO1=bla1,blo1;FOO2=bla2,blo2:bla\r\n"
-        "END:VCARD\r\n\r\n");
+    QByteArray expected("BEGIN:VCARD\r\n"
+                        "VERSION:3.0\r\n"
+                        "EMAIL:foo@kde.org\r\n"
+                        "N:;;;;\r\n"
+                        "UID:testuid\r\n"
+                        "fr;FOO1=bla1,blo1;FOO2=bla2,blo2:bla\r\n"
+                        "END:VCARD\r\n\r\n");
     QCOMPARE(ba, expected);
 }
 
