@@ -62,7 +62,7 @@ void ImportExportVCardTest::shouldExportFullTestVcard4()
                          "UID:urn:uuid:b8767877-b4a1-4c70-9acc-505d3819e519\r\n"
                          "CATEGORIES:FICTION,LITERATURE\r\n"
                          "PRODID:-//KADDRESSBOOK//NONSGML Version 1//EN\r\n"
-                         "REV:2014722T222710Z\r\n"
+                         "REV:20140722T222710Z\r\n"
                          "URL;TYPE=home:https://sherlockholmes.com\r\n"
                          "KEY;MEDIATYPE=application/pgp-keys:https://sherlockholmes.com/sherlock-holmes.pub.asc\r\n"
                          "CALURI;PREF=1:https://sherlockholmes.com/calendar/sherlockholmes\r\n"
@@ -73,7 +73,7 @@ void ImportExportVCardTest::shouldExportFullTestVcard4()
                              "VERSION:4.0\r\n"
                              "ADR;GEO=\"geo:51.523701,0.158500\";LABEL=\"Mr Sherlock Holmes\";TYPE:;;221B Bak\r\n"
                              " er Street;London;;NW1;United Kingdom\r\n"
-                             "ANNIVERSARY:19960415T000000\r\n"
+                             "ANNIVERSARY:19960415\r\n"
                              "BDAY:19531015T231000Z\r\n"
                              "CALADRURI;PREF=1:mailto:detective@sherlockholmes.com\r\n"
                              "CALURI;PREF=1:https://sherlockholmes.com/calendar/sherlockholmes\r\n"
@@ -91,6 +91,7 @@ void ImportExportVCardTest::shouldExportFullTestVcard4()
                              "N:Holmes;Sherlock;;Mr;\r\n"
                              "NICKNAME:Shirley\r\n"
                              "PRODID:-//KADDRESSBOOK//NONSGML Version 1//EN\r\n"
+                             "REV:20140722T222710Z\r\n"
                              "ROLE:Detective\r\n"
                              "TEL;PREF=1;VALUE=uri:ext=5555\r\n"
                              "TEL;TYPE=\"cell,voice\";VALUE=uri:tel:+44-555-555-6666\r\n"
@@ -106,9 +107,75 @@ void ImportExportVCardTest::shouldExportFullTestVcard4()
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
 
     const QByteArray result = vcard.exportVCards(lst, KContacts::VCard::v4_0);
-    qDebug() << " result " << result;
+    //qDebug() << " result " << result;
+    QCOMPARE(result, vcardexpected);
+}
+
+void ImportExportVCardTest::shouldExportMiscElementVcard4()
+{
+    QByteArray vcarddata("BEGIN:VCARD\r\n"
+                         "VERSION:4.0\r\n"
+                         "UID:urn:uuid:4fbe8971-0bc3-424c-9c26-36c3e1eff6b1\r\n"
+                         "FN;PID=1.1:J. Doe\r\n"
+                         "N:Doe;J.;;;\r\n"
+                         "EMAIL;PID=1.1:jdoe@example.com\r\n"
+                         "EMAIL;PID=2.1:boss@example.com\r\n"
+                         "TEL;PID=1.1;VALUE=uri:tel:+1-555-555-5555\r\n"
+                         "TEL;PID=2.1;VALUE=uri:tel:+1-666-666-6666\r\n"
+                         "CLIENTPIDMAP:1;urn:uuid:53e374d9-337e-4727-8803-a1e9c14e0556\r\n"
+                         "END:VCARD\r\n\r\n");
+    QByteArray vcardexpected("BEGIN:VCARD\r\n"
+                             "VERSION:4.0\r\n"
+                             "CLIENTPIDMAP:1;urn:uuid:53e374d9-337e-4727-8803-a1e9c14e0556\r\n"
+                             "EMAIL;PID=1.1:jdoe@example.com\r\n"
+                             "EMAIL;PID=2.1:boss@example.com\r\n"
+                             "FN:J. Doe\r\n"
+                             "N:Doe;J.;;;\r\n"
+                             "TEL;PID=1.1;VALUE=uri:tel:+1-555-555-5555\r\n"
+                             "TEL;PID=2.1;VALUE=uri:tel:+1-666-666-6666\r\n"
+                             "UID:urn:uuid:4fbe8971-0bc3-424c-9c26-36c3e1eff6b1\r\n"
+                             "END:VCARD\r\n\r\n");
+
+    KContacts::VCardTool vcard;
+    const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
+
+    const QByteArray result = vcard.exportVCards(lst, KContacts::VCard::v4_0);
+    //qDebug() << " result " << result;
     QCOMPARE(result, vcardexpected);
 
 }
 
+void ImportExportVCardTest::shouldExportMemberElementVcard4()
+{
+    QByteArray vcarddata("BEGIN:VCARD"
+                         "VERSION:4.0\r\n"
+                         "KIND:group\r\n"
+                         "FN:Funky distribution list\r\n"
+                         "MEMBER:mailto:subscriber1@example.com\r\n"
+                         "MEMBER:xmpp:subscriber2@example.com\r\n"
+                         "MEMBER:sip:subscriber3@example.com\r\n"
+                         "MEMBER:tel:+1-418-555-5555\r\n"
+                         "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\r\n"
+                         "END:VCARD\r\n");
+
+    QByteArray vcardexpected("BEGIN:VCARD\r\n"
+                             "VERSION:4.0\r\n"
+                             "FN:Funky distribution list\r\n"
+                             "KIND:group\r\n"
+                             "MEMBER:mailto:subscriber1@example.com\r\n"
+                             "MEMBER:xmpp:subscriber2@example.com\r\n"
+                             "MEMBER:sip:subscriber3@example.com\r\n"
+                             "MEMBER:tel:+1-418-555-5555\r\n"
+                             "N:;;;;\r\n"
+                             "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\r\n"
+                             "END:VCARD\r\n\r\n");
+
+    KContacts::VCardTool vcard;
+    const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
+
+    const QByteArray result = vcard.exportVCards(lst, KContacts::VCard::v4_0);
+    //qDebug() << " result " << result;
+    QCOMPARE(result, vcardexpected);
+}
+
 QTEST_MAIN(ImportExportVCardTest)
